# neoclima

![image](https://img.shields.io/pypi/pyversions/neoclima?color=brightgreen)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


Modern CLI Weather App


## Installation

```python
  pip install neoclima
```

## Usage

```python
  neoclima add nyc # add new city with chosen nickname
  neoclima now nyc # current weather for nyc
  neoclima edit nyc # edit city nickname
  neoclima rm nyc # remove nyc from cities list
  neoclima ls # list added cities
```

## Stack

```python
  Typer & TinyDB
```
